#!/bin/sh

# Licensed Materials - Property of IBM
# 5725-G92 (C) Copyright IBM Corp. 2011, 2013 . All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

# Usage: server.sh [status|start|stop|open-port]

was_liberty_dir='@WAS_LIBERTY_DIR@'
port='@PORT@'
im_java_home='@IM_JAVA_HOME@'

case "$1" in

  help | -help | --help)
    echo 'Usage: server.sh [status|start|stop|open-port]
Options:
  status     queries whether the server is running or stopped.
  start      starts the server
  stop       stops the server
  open-port  opens the port in the firewall so that mobile devices can
             access the server (only supported on Linux)
'
    ;;

  status | start | stop)
    # The $was_liberty_dir/wlp/bin/server script needs a Java implementation.
    # It tries the following:
    #   1. ${JAVA_HOME}/bin/java
    #   2. ${JRE_HOME}/bin/java
    #   3. ${WLP_DEFAULT_JAVA_HOME}/bin/java
    #   4. 'java' found in $PATH
    # If the user has not set any of these environment variables appropriately,
    # set JAVA_HOME to the IBM Java implementation that comes with
    # Installation Manager.
    # If one of these Java implementations exists but is not at least Java 6,
    # do the same thing, otherwise we get
    # CWWKE0042E: The correct Java version is not running. The runtime environment requires Java 6 or higher.
    if test -n "${JAVA_HOME}" && test -f "${JAVA_HOME}/bin/java"; then
      case `${JAVA_HOME}/bin/java -version 2>&1 | sed -e 's,^[^0-9]*,,' -e '/^$/d' -e 1q` in
        1.1* | 1.2* | 1.3* | 1.4* | 1.5*)
          JAVA_HOME="$im_java_home"
          export JAVA_HOME
          ;;
      esac
    else
      if test -n "${JRE_HOME}" && test -f "${JRE_HOME}/bin/java"; then
        case `${JRE_HOME}/bin/java -version 2>&1 | sed -e 's,^[^0-9]*,,' -e '/^$/d' -e 1q` in
          1.1* | 1.2* | 1.3* | 1.4* | 1.5*)
            JAVA_HOME="$im_java_home"
            export JAVA_HOME
            ;;
        esac
      else
        if test -n "${WLP_DEFAULT_JAVA_HOME}" && test -f "${WLP_DEFAULT_JAVA_HOME}/bin/java"; then
          case `${WLP_DEFAULT_JAVA_HOME}/bin/java -version 2>&1 | sed -e 's,^[^0-9]*,,' -e '/^$/d' -e 1q` in
            1.1* | 1.2* | 1.3* | 1.4* | 1.5*)
              JAVA_HOME="$im_java_home"
              export JAVA_HOME
              ;;
          esac
        else
          if (type java) >/dev/null 2>/dev/null; then
            case `java -version 2>&1 | sed -e 's,^[^0-9]*,,' -e '/^$/d' -e 1q` in
              1.1* | 1.2* | 1.3* | 1.4* | 1.5*)
                JAVA_HOME="$im_java_home"
                export JAVA_HOME
                ;;
            esac
          else
            JAVA_HOME="$im_java_home"
            export JAVA_HOME
          fi
        fi
      fi
    fi

    case "$1" in

      status)
        cd "$was_liberty_dir/wlp/bin" && ./server status worklightServer
        result=$?
        if test $result = 5 || test $result = 27; then
          if (type lsof) >/dev/null 2>/dev/null; then
            if test -n "`lsof -iTCP:$port`"; then
              echo "WAS Liberty server is probably running."
            else
              echo "WAS Liberty server is stopped."
            fi
          fi
        fi
        exit $result
        ;;

      start)
        cd "$was_liberty_dir/wlp/bin" && ./server start worklightServer
        ;;

      stop)
        cd "$was_liberty_dir/wlp/bin" && ./server stop worklightServer
        ;;

    esac
    ;;

  open-port)
    if (type iptables) >/dev/null 2>/dev/null; then
      if sudo iptables -S | grep "^-A INPUT -p tcp -m tcp --dport $port -j ACCEPT"; then
        :
      else
        # Same as:  sudo iptables -I INPUT -p tcp -m tcp -d 0/0 -s 0/0 --dport $port -j ACCEPT
        sudo iptables -I INPUT -p tcp -m tcp --dport $port -j ACCEPT
      fi
    else
      echo "The open-port subcommand works only on Linux with iptables." 1>&2
      exit 1
    fi
    ;;

esac
